<?php
#------ Required Files -------#
include "class.Countries.php";

#------ Extra Fields Class -------#
class ExtFields {

	# Define constants
	const EDIS_OK          = 1;
    const EDIS_FAILED      = 2;
    const EDIS_NEEDED      = 3;
    const EDIS_SAVENOTNEED = 4;

    # Private variables
	private $extData;
	private $sld;
	private $tld;
	private $customContact;
	private $opType;
    private $tos_link;
	
	/**
	* Construct Class Variables
	* @param string $sld: Second level domain
	* @param string $tld: Top level domain
	* @param string $opType: Operation type
	* @param array $customContact: Custom contact sets
	* @param array $extData: Additional fields data
	**/
	public function __construct($sld, $tld, $opType, $customContact, $extData, $tos_link) {
		$this->extData = $extData;
		$this->sld = $sld;
		$this->tld = $tld;
		$this->customContact = $customContact;
		$this->opType = $tld;
        $this->tos_link = $tos_link;
	}
	
	/**
	* Construct Additional Fields
	* @return array $params: Additional fields data
	**/
	public function getFields() {
		# Create new instance of Countries class
		$countries = new Countries();
		# Initiate variables
		$tld = $this->tld;
		$extFields = array();

        # Default DA TOS for all gTLD
        if(strlen($tld) > 2) {
            $extFields["TOS"] = array(
                "type" => "tickbox",
                "title" => _("Term of Service"),
                "description" => _("I agree to have my registrar act as my designated agent for my domain name. 
                Full terms of service can be reviewed here: {$this->tos_link}"),
                "required" => 1,
                "status" => self::EDIS_NEEDED
            );
        }

        # Set owner confirm address field for specific TLDs
		if (in_array($tld, array("de", "be", "eu", "it"))) {
			$extFields["OwnerConfirmAddress"] = array(
				"type" => "text",
                "title" => _("Owner Confirm Address"),
                "description" => _("The email address to which to send messages regarding a transfer."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
		}
		
		# Set international setting
		if ($this->isIdn($this->sld)) {
			$status = self::EDIS_NEEDED;
			$required = true;
			$value = "";
			if (isset($this->extData["IdnLang"])) {
				$status = self::EDIS_OK;
				$value = $this->extData["IdnLang"];
			}		
		}

		#.PRO 
		if ($tld == "pro") {
			$extFields["PRO_Authority"] = array(
				"type" => "text",
                "title" => _("Authority"),
                "description" => _("The name of the authority from which the registrant receives their professional credentials."),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["PRO_AuthorityWebsite"] = array(
				"type" => "text",
                "title" => _("Authority website"),
                "description" => _("The URL to an online resource for the authority, preferably, a member search directory."),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["PRO_LicenseNumber"] = array(
				"type" => "text",
                "title" => _("License number"),
                "description" => _("The license number of the registrant's credentials, if applicable."),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

            $extFields["PRO_Profession"] = array(
            	"type" => "text",
                "title" => _("Profession"),
                "description" => _("The stated profession of the registrant."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
            
            foreach(array("PRO_Authority","PRO_AuthorityWebsite","PRO_LicenseNumber","PRO_Profession") as $key) {
            	if (isset($this->extData[$key])) {
            		$value = trim($this->extData[$key]);
            		if($extFields[$key]["required"] && strlen($value) == 0) {
            			$extFields[$key]["status"] = self::EDIS_FAILED;
            		} else {
            			$extFields[$key]["status"] = self::EDIS_OK;
            			$extFields[$key]["defaultValue"] = $value;
            		}
            	}
            }		
		}
		
		#.ASIA
		if ($tld == "asia") {
			$extFields["ASIA_ContactType"] = array(
				"type" => "dropdown",
                "title" => _("Contact Type"),
                "description" => _("Specify which contact will be designated the Charter Eligibility Declaration (CED) Contact."),
                "options" => array(
                	'owner|' ._('Owner'),
                	'admin|' ._('Admin'),
                	'tech|' ._('Technical'),
                	'billing|' ._('Billing')
                	),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

            $extFields["ASIA_IdNumber"] = array(
            	"type" => "text",
                "title" => _("ID Number"),
                "description" => _("Identification number or code of reference for the specified ID type; e.g., a passport number."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

            $extFields["ASIA_IdType"] = array(
            	"type" => "dropdown",
                "title" => _("Type of ID"),
                "options" => array(
                	'passport|' ._('Passport'),
                	'certificate|' ._('Certificate (of Incorporation or business registration)'),
                	'legislation|' ._('Legislation (act/decree/legislation chartering the formation of an entity)'),
                	'societyRegistry|' ._('Society Registry'),
                	'politicalPartyRegistry|' ._('Political Party Registry'),
                	'other|' ._('Other')
                	),
                "description" => _("Specify the type of ID to validate the CED information."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

            if (isset($this->extData["ASIA_IdType"]) && $this->extData["ASIA_IdType"] === "other") {        
				$extFields["ASIA_IdTypeInfo"] = array(
						"type" => "text",
						"title" => _("Type of ID Description"),
						"description" => _("A description of the ID type."),
						"required" => 1, 
						"status" => self::EDIS_NEEDED
						);
        	}

        	$extFields["ASIA_LegalEntityType"] = array(
        		"type" => "dropdown",
                "title" => _("Legal Entity Type"),
                "options" => array(
                	'naturalPerson|' ._('Natural Person'),
					'corporation|' ._('Corporation'),
					'cooperative|' ._('Cooperative'),
					'partnership|' ._('Partnership'),
					'government|' ._('Goverment'),
					'politicalParty|' ._('Political Party'),
					'society|' ._('Society'),
					'institution|' ._('Institution'),
					'other|' ._('Other')
					),
                "description" => _("The legal entity type of the CED."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
            
            if (isset($this->extData["ASIA_LegalEntityType"]) && $this->extData["ASIA_LegalEntityType"] === "other") {
            	$extFields["ASIA_LegalEntityTypeInfo"] = array(
            			"type" => "text",
						"title" => _("Legal Entity Type Description"),
						"description" => _("A description of the legal entity type."),
						"required" => 1, 
						"status" => self::EDIS_NEEDED
						);
            }
            
            $extFields["ASIA_LocalityCountry"] = array(
            	"type" => "dropdown",
                "title" => _("Locality Country"),
                "options" => $countries->getCountries(Countries::$FILTER_ASIA, true),
                "description" => _("Country Code."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

            $extFields["ASIA_LocalityStateProv"] = array(
            	"type" => "text",
				"title" => _("Locality State/Province"),
				"description" => _("The state or province where the CED contact resides."),
				"required" => 0,
				"status" => self::EDIS_NEEDED
				);
			
			$extFields["ASIA_LocalityCity"] = array(
				"type" => "text",
				"title" => _("Locality City"),
				"description" => _("The city where the CED contact resides."),
				"required" => 0, 
				"status" => self::EDIS_NEEDED
				);
						
			foreach(array("ASIA_IdNumber","ASIA_IdTypeInfo","ASIA_LegalEntityTypeInfo","ASIA_LocalityStateProv", "ASIA_LocalityCity") as $key) {
            	if (isset($this->extData[$key]) && isset($extFields[$key])) {
            		$value = trim($this->extData[$key]);
            		if($extFields[$key]["required"] && strlen($value) == 0) {
            			$extFields[$key]["status"] = self::EDIS_FAILED;
            		} else {
            			$extFields[$key]["status"] = self::EDIS_OK;
            			$extFields[$key]["defaultValue"] = $value;
            		}
            	}
            }		
		}
		
		#.COM.AU /.NET.AU /.ORG.AU /.ASN.AU /.ID.AU
		if (in_array($tld, array("com.au", "net.au", "asn.au", "id.au", "org.au"))) {

			# For com.au, net.au, org.au, asn.au
			if (in_array($tld, array("com.au", "net.au", "org.au", "asn.au"))) {
				$extFields["AU_EligibilityIdType"] = array(
					"type" => "dropdown",
	                "title" => _("Eligibility ID Type"),
	                "options" => array(
	                	"ACN|" ._("Australian Company Number"),
						"ABN|" ._("Australian Business Number"),
						"VIC BN|" ._("Victoria Business Number"),
						"NSW BN| " ._("New South Wales Business Number"),
						"SA BN|" ._("South Australia Business Number"),
						"NT BN|" ._("Northern Territory Business Number"),
						"WA BN|" ._("Western Australia Business Number"),
						"TAS BN|" ._("Tasmania Business Number"),
						"ACT BN|" ._("Australian Capital Territory Business Number"),
						"QLD BN|" ._("Queensland Business Number"),
						"TM|" ._("TM"),
						"OTHER|" ._("Other")
						),
	                "description" => _("The Eligibility ID type"),
	                "required" => 1,
	                "status" => self::EDIS_NEEDED
	                );

				$extFields["AU_EligibilityId"] = array(
					"type" => "text",
	                "title" => _("Eligibility ID"),
	                "description" => _("The identifier of the eligibility document. Important: This number will be verified, and if you submit an incorrect number, the registration will fail."),
	                "required" => 1, 
	                "status" => self::EDIS_NEEDED
	                );

				$extFields["AU_EligibilityName"] = array(
					"type" => "text",
					"title" => _("Eligibility Name"),
					"description" => _("The name on the eligibility ID document."),
					"required" => 1,
					"status" => self::EDIS_NEEDED
					);		
			}

			# For asn.au and org.au
			if (in_array($tld, array("org.au", "asn.au"))) {
				$extFields["AU_EligibilityType"] = array(
					"type" => "dropdown", 
					"title" => _("Eligibility Type"),
					"options" => array(
						"Charity|" ._("Charity"),
						"Club|" ._("Club"),
						"Incorporated|" ._("Incorporated"),
						"Non-profit Organization|" ._("Non-profit Organization"),
						"Trade Union|" ._("Trade Union")
						),
					"description" => _("The reason that the registrant is eligible for the domain name. The eligibility type must correspond to the eligibility name."),
					"required" => 1,
					"status" => self::EDIS_NEEDED
					);
			}

			# For com.au and net.au
			if (in_array($tld, array("com.au", "net.au"))) {
				$extFields["AU_EligibilityType"] = array(
					"type" => "dropdown", 
					"title" => _("Eligibility Type"),
					"options" => array(
						"Company|" ._("Company"),
						"Partnership|" ._("Partnership"),
						"Pending TM Owner|" ._("Pending TM Owner"),
						"Registered Business|" ._("Registered Business"),
						"Sole Trader|" ._("Sole Trader"),
						"Trademark Owner|" ._("Trademark Owner")
						),
					"description" => _("The reason that the registrant is eligible for the domain name. The eligibility type must correspond to the eligibility name."),
					"required" => 1,
					"status" => self::EDIS_NEEDED
					);
			}

			$extFields["AU_RegistrantIdType"] = array(
				"type" => "dropdown",
                "title" => _("Registrant ID Type"),
                "options" => array(	
					"ACN|" ._("Australian Company Number (ACN)"),
					"ABN|" ._("Australian Business Number (ABN)")
					),
                "description" => _("Registrant ID Type."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["AU_RegistrantId"] = array(
				"type" => "text",
                "title" => _("Registrant ID"),
                "description" => _("The registrant identifier. Must correspond to registrant type (ABN or ACN). Important: This number will be verified, and if you submit an incorrect number, the registration will fail."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["AU_RegistrantName"] = array(
				"type" => "text",
                "title" => _("Registrant Name"),
                "description" => _("The legal entity such as a company, incorporated association, government agency or individual person. Cannot be a registered business name or trademark."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
		}

		#.BE
		if ($tld == "be") {
			$extFields["BE_Lang"] = array(
				"type" => "dropdown",
                "title" => _("Preferred Language"),
                "options" => array(
                	"en|" ._("English"),
                	"fr|" ._("French"),
                	"nl|" ._("Dutch")
                	),
                "description" => _("Preferred language."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
		}

		#.US
		if ($tld == "us") {
			$extFields["US_AppPurpose"] = array(
				"type" => "dropdown",
                "title" => _("Application purpose"),
                "options" => array(	
					"P1|" ._("Business use for non profit"),
					"P2|" ._("Non-profit business (e.g. Club/Association/Religious organization)"),
					"P3|" ._("Personal use"),
					"P4|" ._("Education purposes"),
					"P5|" ._("Government purposes")
					),
                "description" => _("A description of the domain's application purpose."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
			
			$extFields["US_Category"] = array(
				"type" => "dropdown",
                "title" => _("Category"),
                "options" => array(	
					"C11|" ._("A citizen of the U.S. or any of its territories"),
					"C12|" ._("A permanent resident of the U.S. or any of its territories"),
					"C21|" ._("An organization incorporated within the U.S."),
					"C31|" ._("An entity that regularly engages in lawful activities in the U.S."),
					"C32|" ._("An entity that has an office or other facility in the U.S.")
					),
                "description" => _("A description of the domain's category."),
                "required"    => 1, 
                "status"      => self::EDIS_NEEDED
                );

            $extFields["US_Validator"] = array(
            	"type" => "dropdown",
            	"title" => _("Validator"),
            	"options" => $countries->getCountries(Countries::$FILTER_ALL, true),
            	"description" => _("The domain owner's country of citizenship."),
            	"required" => 1,
            	"status" => self::EDIS_NEEDED
            	);				
		}
		
		#.CA
		if ($tld == "ca") {
			$extFields["CA_LegalType"] = array(
				"type" => "dropdown",
                "title" => _("Legal Type"),
                "options" => array(	
					"ABO|" ._("Aboriginal"),
					"ASS|" ._("Association"),
					"CCO|" ._("Canadian Corporation"),
					"CCT|" ._("Canadian Citizen"),
					"EDU|" ._("Educational Institution"),
					"GOV|" ._("Government"),
					"HOP|" ._("Hospital"),
					"INB|" ._("Indian Band"),
					"LAM|" ._("Library/Archive/Museum"),
					"LGR|" ._("Legal Representative"),
					"MAJ|" ._("Her Majesty the Queen"),
					"OMK|" ._("Protected by Trademarks Act"),
					"PLT|" ._("Political Party"),
					"PRT|" ._("Partnership"),
					"RES|" ._("Permanent Resident"),
					"TDM|" ._("Trademark Owner"),
					"TRD|" ._("Trade Union"),
					"TRS|" ._("Trust")
					),
                "description" => _("Domain name owner's legal classification."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["CA_LegalAgreement"] = array(
				"type" => "tickbox",
                "title" => _("CIRA Agreement"),
                "description" => _("You have read, understood and agree to the terms and conditions of the Registrant 
                Agreement, and that CIRA may, from time to time and at its discretion, amend any or all of the terms 
                and conditions of the Registrant Agreement, as CIRA deems appropriate, by posting a notice of the 
                changes on the CIRA website and by sending a notice of any material changes to Registrant. You meet 
                all the requirements of the Registrant Agreement to be a Registrant, to apply for the registration 
                of a Domain Name Registration, and to hold and maintain a Domain Name Registration, including without 
                limitation CIRA's Canadian Presence Requirements for Registrants, 
                at: www.cira.ca/assets/Documents/Legal/Registrants/CPR.pdf. CIRA will collect, use and disclose 
                your personal information, as set out in CIRA's Privacy Policy, 
                at: www.cira.ca/assets/Documents/Legal/Registrants/privacy.pdf"),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["CA_LangPref"] = array(
				"type" => "dropdown",
				"title" => _("Language Prefrence"),
				"options" => array(
					"en|" ._("English"),
					"fr|" ._("French")
					),
				"description" => _("Preferred lanage of communication."),
				"required" => 1,
				"status" => self::EDIS_NEEDED
				);			            
		}
		
		#.IT
		if ($tld == "it") {
			$nationalityCode1 = $countries->getCountries(Countries::$FILTER_EU, true);
			$nationalityCode2_6 = $countries->getCountries(array("IT"), true);
			$nationalityCode7 = $nationalityCode1;
			unset($nationalityCode7["IT"]);			
		
			$extFields["IT_RegistrantCode"] = array(
				"type" => "text",
                "title" => _("Registrant Code"),
                "description" => _("An identifying number, usually the VAT or Codice Fiscale (numeric tax code). The value that you need to enter depends on the entity type of the registrant."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
		
			$extFields["IT_EntityType"] = array(
				"type" => "dropdown",
                "title" => _("Entity Type"),
                "options" => array(	
					"1|" ._("Italian and foreign natural persons"),
					"2|" ._("Companies/one man companies"),
					"3|" ._("Freelance workers/professionals"),
					"4|" ._("Non-profit organizations"),
					"5|" ._("Public organizations"),
					"6|" ._("Other subjects"),
					'7|' ._('Foreigners who match "Companies/one man companies" or "Other subjects"')
					),
                "description" => _("Entry that indicates the type of domain owner."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );
            
                          
			$extFields["IT_NationalityCode"] = array(
				"type" => "dropdown",
                "title" => _("Nationality Code"),
                "options" => $nationalityCode1,
                "description" => _("Entry that indicates the type of domain owner."),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );		
		}

		#.FR
		if ($tld == "fr") {
			$country_list = $countries->getCountries(Countries::$FILTER_ALL, true);

			$extFields["FR_RegistrantType"] = array(
				"type" => "dropdown",
                "title" => _("Registrant type"),
                "options" => array(
                	"individual|" ._("Individual"),
                	"organization|" ._("Organization")
                	),
                "description" => "Registrant type.",
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_CountryOfBirth"] = array(
				"type" => "dropdown",
                "title" => _("Country of birth"),
                "options" => $country_list,
                "description" => _("Country of birth. (Required for registrant type Individuals)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_DateOfBirth"] = array(
				"type" => "text",
                "title" => _("Date of Birth"),
                "description" => _("Registrant's date of birth (ie. YYYY-MM-DD) (Required for registrant type Individuals)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_PlaceOfBirth"] = array(
				"type" => "text",
                "title" => _("Place of birth"),
                "description" => _("Registrant's place of birth. If born in France, please provide the POSTAL CODE and city/town (e.g., 75001, Paris). If born outside of France, only the country code is required (e.g., GB) (Required for registrant type Individuals)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_PostalCodeOfBirth"] = array(
				"type" => "text",
                "title" => _("Postal Code of Birth"),
                "description" => _("Postal Code of Birth. (Required for registrant type Individuals)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_BusinessRegNumber"] = array(
				"type" => "text",
                "title" => _("Registration Number"),
                "description" => _("Business registration number (SIREN/SIRET/INPI) or, if applicable, the registration number of trademark on the domain (trademark must be recognized in France)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_TrademarkNumber"] = array(
				"type" => "text",
                "title" => _("Trademark Number"),
                "description" => _("The organization's trademark registration number, if applicable."),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields["FR_RegistrantVatId"] = array(
				"type" => "text",
                "title" => _("VAT Registration Number of the Organization"),
                "description" => _("The Value Added Tax (VAT) registration number of the organization, if applicable."),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );	
		}

		#.SE /.NU
		if (in_array($tld, array('se', 'nu'))){
			$extFields['SE_RegistrantType'] = array(
				"type" => "dropdown",
                "title" => _("Registrant Type"),
                "options" => array(
                	"individual|" ._("Individual"),
                	"organization|" ._("Organization")
                	),
                "description" => _("Registrant Type"),
                "required" => 1, 
                "status" => self::EDIS_NEEDED
                );

			$extFields['SE_IdCardNumber'] = array(
				"type" => "text",
                "title" => _("Registrant's ID card number"),
                "description" => _("Registrant's ID card number. (Required if registrant type is Individual)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );


			$extFields['SE_RegistrantVatId'] = array(
				"type" => "text",
                "title" => _("VAT Number"),
                "description" => _("The Value Added Tax (VAT) number of the organization. (Required for registrant type Organization only)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );

			$extFields['SE_RegistrationNumber'] = array(
				"type" => "text",
                "title" => _("Business Number"),
                "description" => _("The business number of the organization. (Required for registrant type Organization only)"),
                "required" => 0, 
                "status" => self::EDIS_NEEDED
                );
		}
		
		# Construct drop down lists
		foreach ($extFields as $key => $value) {
			if ($extFields[$key]["type"] == "dropdown" && is_array($extFields[$key]["options"])) {
				$extFields[$key]["options"] = implode(',', $extFields[$key]["options"]);
			}
		}
		
		# Return additional required fields
		return $extFields;	
	}
	
	# Check if domain is in international format
	private function isIdn($domain) {
		if (strpos($domain, 'xn--') === false) {
			return false;
		}
		return true;
	}
}
?>